<?php

/**
 * The public-facing functionality of the plugin.
 *
 * @link       https://ays-pro.com/
 * @since      1.0.0
 *
 * @package    Ays_Facebook_Popup_Likebox
 * @subpackage Ays_Facebook_Popup_Likebox/public
 */

/**
 * The public-facing functionality of the plugin.
 *
 * Defines the plugin name, version, and two examples hooks for how to
 * enqueue the public-facing stylesheet and JavaScript.
 *
 * @package    Ays_Facebook_Popup_Likebox
 * @subpackage Ays_Facebook_Popup_Likebox/public
 * @author     AYS Pro LLC <info@ays-pro.com>
 */
class Ays_Facebook_Popup_Likebox_Public {

	/**
	 * The ID of this plugin.
	 *
	 * @since    1.0.0
	 * @access   private
	 * @var      string    $plugin_name    The ID of this plugin.
	 */
	private $plugin_name;

	/**
	 * The version of this plugin.
	 *
	 * @since    1.0.0
	 * @access   private
	 * @var      string    $version    The current version of this plugin.
	 */
	private $version;

	/**
	 * Initialize the class and set its properties.
	 *
	 * @since    1.0.0
	 * @param      string    $plugin_name       The name of the plugin.
	 * @param      string    $version    The version of this plugin.
	 */
	public function __construct( $plugin_name, $version ) {

		$this->plugin_name = $plugin_name;
		$this->version = $version;

	}

	/**
	 * Register the stylesheets for the public-facing side of the site.
	 *
	 * @since    1.0.0
	 */
	public function enqueue_styles() {

		/**
		 * This function is provided for demonstration purposes only.
		 *
		 * An instance of this class should be passed to the run() function
		 * defined in Ays_Facebook_Popup_Likebox_Loader as all of the hooks are defined
		 * in that particular class.
		 *
		 * The Ays_Facebook_Popup_Likebox_Loader will then create the relationship
		 * between the defined hooks and the functions defined in this
		 * class.
		 */
        wp_enqueue_style( 'fontawesom-afpl', '//cdnjs.cloudflare.com/ajax/libs/font-awesome/4.7.0/css/font-awesome.min.css', array(), $this->version, 'all' );
		wp_enqueue_style( $this->plugin_name, plugin_dir_url( __FILE__ ) . 'css/ays-facebook-popup-likebox-public.css', array(), $this->version, 'all' );
		wp_enqueue_style( 'animate_fpl', plugin_dir_url( __FILE__ ) . 'css/animate.css', array(), $this->version, 'all' );

	}

	/**
	 * Register the JavaScript for the public-facing side of the site.
	 *
	 * @since    1.0.0
	 */
	public function enqueue_scripts() {

		/**
		 * This function is provided for demonstration purposes only.
		 *
		 * An instance of this class should be passed to the run() function
		 * defined in Ays_Facebook_Popup_Likebox_Loader as all of the hooks are defined
		 * in that particular class.
		 *
		 * The Ays_Facebook_Popup_Likebox_Loader will then create the relationship
		 * between the defined hooks and the functions defined in this
		 * class.
		 */

		wp_enqueue_script( 'jquery-effects-core' );
        wp_enqueue_script( 'jquery-ui-sortable' );
        wp_enqueue_media();
		// wp_enqueue_script( $this->plugin_name, plugin_dir_url( __FILE__ ) . 'js/ays-fb-pl.js', array( 'jquery' ), $this->version, false );
		wp_enqueue_script( $this->plugin_name, plugin_dir_url( __FILE__ ) . 'js/ays-facebook-popup-likebox-public.js', array( 'jquery' ), $this->version, false );

	}

    public function ays_initialize_fbl_shortcode(){ 
		add_shortcode( 'ays_fb_popup_likebox', array($this, 'ays_generate_fblikebox') );
    }
	
    public function ays_fb_set_cookie($attr){
		
        $cookie_time = $attr['cookie'];
        $cookie_name = 'ays_fb_popup_cookie_'.$attr['id'];
        $cookie_value = $attr['title'];
        $cookie_expiration =  time() + ($cookie_time * 60);
		$aaaa = [$cookie_time, $cookie_name, $cookie_value, $cookie_expiration];		
        setcookie($cookie_name, $cookie_value, $cookie_expiration, '/');


    }	
	
	public function ays_generate_fblikebox( $attr ){
        
        $id = ( isset($attr['id']) ) ? absint( intval( $attr['id'] ) ) : null;
		$fblikebox = $this->get_fb_likebox_by_id($id);
		if(isset($fblikebox['onoffswitch']) && $fblikebox['onoffswitch'] == 'On'){	         

			if(!isset($_COOKIE['ays_fb_popup_cookie_'.$id])){
				$this->ays_fb_set_cookie($fblikebox);
			}else{                               
				return;
			}

            $ays_fb_language                = isset($fblikebox["lang"]) && $fblikebox["lang"] != '' ? $fblikebox["lang"] : 'en_US';

            $ays_fb_lang_array = array(
                'lang' => $ays_fb_language
            );
            echo "<script>
                var ays_fb_language = ".json_encode($ays_fb_lang_array).";
            </script>";


            $ays_fb_url                     = $fblikebox["url"];
			$ays_fb_content                 = explode('***', $fblikebox["content"]);
			$ays_fb_content                 = implode(',', $ays_fb_content);
			$ays_fb_header_options          = explode('***', $fblikebox["header_options"]);
			$ays_fb_width                   = $fblikebox["width"];
			$ays_fb_height                  = $fblikebox["height"];
			$ays_fb_autoclose               = $fblikebox["autoclose"];
			$ays_fb_show_all                = $fblikebox["show_all"];
			$ays_fb_likebox_title           = __($fblikebox["title"], $this->plugin_name);
			$ays_fb_likebox_description     = __($fblikebox["description"], $this->plugin_name);
			$ays_fb_bgcolor					= $fblikebox["bgcolor"];
			$ays_fb_textcolor				= $fblikebox["textcolor"];
			$ays_fb_bordersize				= $fblikebox["bordersize"];
			$ays_fb_bordercolor				= $fblikebox["bordercolor"];
			$ays_fb_border_radius			= $fblikebox["border_radius"];
			$ays_fb_custom_css              = $fblikebox["custom_css"];
            $ays_fb_click_to_action         = $fblikebox["click_to_action"];
            $ays_fb_view_place              = explode( '***', $fblikebox["view_place"] );
            $ays_fb_delay                   = $fblikebox["delay"];
            $ays_fb_scroll_top              = $fblikebox["scroll_top"];
			$ays_fb_animate_in              = $fblikebox["animate_in"];
			$ays_fb_animate_out             = $fblikebox["animate_out"];

            if($ays_fb_delay == 0 && $ays_fb_scroll_top == 0){
                $open = "checked";
                $ays_fb_animate_in_open = $ays_fb_animate_in;
            }else{                
                $open = "";
                $ays_fb_animate_in_open = "";
            }
            $fbpl_locale = get_locale();
            
			$fblikebox_view = '<style>'.$ays_fb_custom_css.'</style>
				<div class="ays-fpl-modals">
                    <input type="hidden" value="'.$ays_fb_animate_in.'" id="ays_fpl_modal_animate_in_'.$id.'">
                    <input type="hidden" value="'.$ays_fb_animate_out.'" id="ays_fpl_modal_animate_out_'.$id.'">
					<input id="ays-fpl-modal-checkbox_'.$id.'" class="ays-fpl-modal-check" type="checkbox" '.$open.'/>
					<div class="ays-fpl-modal ays-fpl-modal_'.$id.' '.$ays_fb_animate_in_open.'" style="width: '.$ays_fb_width.'px; height: '.$ays_fb_height.'px; background-color: '.$ays_fb_bgcolor.'; color: '.$ays_fb_textcolor.' !important; border: '.$ays_fb_bordersize.'px solid '.$ays_fb_bordercolor.'; border-radius: '.$ays_fb_border_radius.'px; ">
						<label for="ays-fpl-modal-checkbox_'.$id.'" class="ays-fpl-modal-close ays-fpl-modal-close_'.$id.'"><i class="fa fa-times fa-2x"></i></label>
						<h2 style="color: '.$ays_fb_textcolor.'">'.$ays_fb_likebox_title.'</h2>
						<p>'.$ays_fb_likebox_description.'</p>
						<hr />
						<div class="ays_fpl_container">
							<div class="fb-page"
								 data-href="'.$ays_fb_url.'"
								 data-tabs="'.$ays_fb_content.'"
								 data-small-header="'.((in_array('small_header', $ays_fb_header_options)) ? "true" : "false" ).'"
								 data-height="'.( intval($ays_fb_height) - 200 ).'"
                                 data-width="'.(intval($ays_fb_width)).'"
								 data-hide-cover="'.((in_array('hide_cover_photo', $ays_fb_header_options)) ? "true" : "false" ).'"
								 data-show-facepile="'.((in_array('show_friend_faces', $ays_fb_header_options)) ? "true" : "false" ).'"
								 data-hide-cta="'.($ays_fb_click_to_action).'"
								 data-adapt-container-width="false">
								<blockquote cite="'.$ays_fb_url.'" class="fb-xfbml-parse-ignore">
									<a href="'.$ays_fb_url.'"></a>
								</blockquote>
							</div>
                        </div>';
                        if ($ays_fb_autoclose>0) {
                            $fblikebox_view .= '<p class="ays_fpl_timer ays_fpl_timer_'.$id.'">'.(__("This will close in ", $this->plugin_name)).'<span data-seconds="'.$ays_fb_autoclose.'"> '.$ays_fb_autoclose.' </span> seconds</p>';
                        }
					$fblikebox_view .= '</div>
					<div id="ays-fpl-screen-shade_'.$id.'"></div>
                    <input type="hidden" class="ays_fpl_delay_'.$id.'" value="'.$ays_fb_delay.'"/>
                    <input type="hidden" class="ays_fpl_scroll_'.$id.'" value="'.$ays_fb_scroll_top.'"/>
                    <input type="hidden" class="ays_fpl_locale" value="'.$fbpl_locale.'"/>
				</div>';
            
               $fblikebox_view .= "
                <style>                    
                    .ays-fpl-modal-check:checked ~ #ays-fpl-screen-shade_".$id." {
                        opacity: 0.5;
                        pointer-events: auto;
                    }

                    #ays-fpl-screen-shade_".$id." {
                        opacity: 0;
                        background: #000;
                        position: absolute;
                        left: 0;
                        right: 0;
                        top: 0;
                        bottom: 0;
                        pointer-events: none;
                        transition: opacity 0.8s;
                    }
                </style>
                <script>
                (function( $ ) {
                    'use strict';
                    $(document).ready(function(){
                        let time_fpl_".$id." = $(document).find('p.ays_fpl_timer_".$id." span').data('seconds');
                        let ays_fpl_effectOut_".$id." = $(document).find('#ays_fpl_modal_animate_out_".$id."').val();
                        
                        if(time_fpl_".$id." !== undefined){
                            let timer_fpl_".$id." = setInterval(function(){
                                let newTime_fpl_".$id." = time_fpl_".$id."--;
                                
                                $(document).find('p.ays_fpl_timer_".$id." span').text(newTime_fpl_".$id.");
                                if(newTime_fpl_".$id." <= 0){
                                    $(document).find('.ays-fpl-modal-close_".$id."').trigger('click');
                                    $(document).find('.ays-fpl-modal_".$id."').attr('class', 'ays-fpl-modal ays-fpl-modal_".$id." '+ays_fpl_effectOut_".$id.");
                                    setTimeout(function(){ $(document).find('.ays-fpl-modal_".$id."').css('display', 'none');}, 500);
                                    clearInterval(timer_fpl_".$id.");
                                }
                                
                            },1000);
                        }
                        $(document).find('.ays-fpl-modal-close_".$id."').on('click', function(){
                            $(document).find('.ays-fpl-modal_".$id."').attr('class', 'ays-fpl-modal ays-fpl-modal_".$id." '+ays_fpl_effectOut_".$id.");
                            setTimeout(function(){ $(document).find('.ays-fpl-modal_".$id."').css('display', 'none'); }, 400);  
                            setTimeout(function(){ $(document).find('#ays-fpl-screen-shade_".$id."').css({'opacity': '0', 'display': 'none'}); }, 500);
                            setTimeout(function(){ $(document).find('.ays-fpl-modal_".$id."').remove(); }, 500);
                        });
                        let ays_fpl_scrollTop_".$id." = Number($(document).find('.ays_fpl_scroll_".$id."').val()),
                            ays_fpl_delayOpen_".$id." = Number($(document).find('.ays_fpl_delay_".$id."').val()),
                            ays_fpl_effectIn_".$id." = $(document).find('#ays_fpl_modal_animate_in_".$id."').val();
                        if( ays_fpl_scrollTop_".$id." !== 0 ){
                            $(window).scroll(function() {
                                if($(this).scrollTop() >= ays_fpl_scrollTop_".$id.") {
                                    if( ays_fpl_delayOpen_".$id." !== 0 ){                        
                                        $(document).find('.ays-fpl-modal_".$id."').css('animation-delay', ays_fpl_delayOpen_".$id."/1000);
                                        setTimeout(function(){
                                            $(document).find('.ays-fpl-modal_".$id."').addClass(ays_fpl_effectIn_".$id.");
                                            $(document).find('.ays-fpl-modal_".$id."').css('display', 'block');
                                            $(document).find('#ays-fpl-screen-shade_".$id."').css({'opacity': '0.5'});
                                            $(document).find('#ays-fpl-modal-checkbox_".$id."').prop('checked', true);
                                        }, ays_fpl_delayOpen_".$id.");
                                    }else{
                                        $(document).find('.ays-fpl-modal_".$id."').addClass(ays_fpl_effectIn_".$id.");
                                        $(document).find('.ays-fpl-modal_".$id."').css('display', 'block');
                                        $(document).find('#ays-fpl-screen-shade_".$id."').css({'opacity': '0.5'});
                                        $(document).find('#ays-fpl-modal-checkbox_".$id."').prop('checked', true);
                                    }
                                }
                            });
                        }else{
                            if( ays_fpl_delayOpen_".$id." !== 0 ){
                                $(document).find('.ays-fpl-modal_".$id."').css('animation-delay', ays_fpl_delayOpen_".$id."/1000);
                                setTimeout(function(){
                                    $(document).find('.ays-fpl-modal_".$id."').addClass(ays_fpl_effectIn_".$id.");
                                    $(document).find('.ays-fpl-modal_".$id."').css('display', 'block');
                                    $(document).find('#ays-fpl-screen-shade_".$id."').css({'opacity': '0.5'});
                                    $(document).find('#ays-fpl-modal-checkbox_".$id."').prop('checked', true);
                                }, ays_fpl_delayOpen_".$id.");
                            }else{
                                $(document).find('.ays-fpl-modal_".$id."').addClass(ays_fpl_effectIn_".$id.");
                                $(document).find('.ays-fpl-modal_".$id."').css('display', 'block');
                                $(document).find('#ays-fpl-screen-shade_".$id."').css({'opacity': '0.5'});
                                $(document).find('#ays-fpl-modal-checkbox_".$id."').prop('checked', true);
                            }
                        }
                    });
                    })( jQuery );
                </script>";
            return $fblikebox_view;			
		}
    }

    public function ays_fbl_shortcodes_show_all(){
        global $wpdb;    
        $post_id = get_the_ID();
        $sql2 = "SELECT * FROM {$wpdb->prefix}ays_fbl WHERE view_place <> '' ";
        $result2 = $wpdb->get_results($sql2, "ARRAY_A");
        if(!empty($result2)){
            foreach($result2 as $key => $i){
                $ays_fb_view_place  = explode( '***', $i["view_place"] );
                if(in_array($post_id, $ays_fb_view_place)){
                    $shortcode2 = "[ays_fb_popup_likebox id={$i['id']} w={$i['width']} h={$i['height']} ]";
                    echo do_shortcode($shortcode2);
                }
            }
        }
        $sql = "SELECT * FROM {$wpdb->prefix}ays_fbl WHERE show_all = 'yes'";
        $result = $wpdb->get_results($sql, "ARRAY_A");
        if(!empty($result)){
            foreach($result as $key => $i){
                $shortcode = "[ays_fb_popup_likebox id={$i['id']} w={$i['width']} h={$i['height']} ]";
                echo do_shortcode($shortcode);
            }
        }
        
    }
	
	public function get_fb_likebox_by_id( $id ){
        global $wpdb;

        $sql = "SELECT * FROM {$wpdb->prefix}ays_fbl WHERE id=" . absint( intval( $id ) );

        $result = $wpdb->get_row($sql, "ARRAY_A");

        return $result;
    }

    private function array_split($array, $pieces) {
        if ($pieces < 2)
            return array($array);
        $newCount = ceil(count($array)/$pieces);
        $a = array_slice($array, 0, $newCount);
        $b = $this->array_split(array_slice($array, $newCount), $pieces-1);
        return array_merge(array($a),$b);
    }
}
